#' @name PaulinoTb1.1
#' @title Acidentes Rodoviários Ocorridos na Suécia
#' @description Durante 18 semanas, no ano de 1961, contou-se o número de acidentes 
#'     rodoviários registrados na Suécia segundo o tipo de estrada e o
#'     fato de haver ou não um limite de velocidade de 90 km/h no dia
#'     em que ocorreram. Pretendia-se investigar se a 
#'     imposição do limite de velocidade estava relacionado à ocorrência de
#'     acidentes e a relação com o tipo de estrada.
#' @format Um \code{data.frame} com 4 observações e 3 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{veloc}}{Existência ou não do limite de velocidade de 90
#'      km/h.}
#'
#' \item{\code{estr}}{Tipo de estrada (auto-estrada, outras).}
#'
#' \item{\code{acid}}{Número de acidentes registrados.}
#'
#' }
#' @keywords contingência
#' @source Paulino, C. D., Singer, J. M. (2006). Análise de Dados 
#'     Categorizados (1st ed.). São Paulo, SP: Edgard Blucher.
#'     (Tabela 1.1, pág. 04)
#'
#' @references Rasch, G. (1973) Two applications of the multiplicative
#'     Poisson model in road accident statistics, Proceedings of the
#'     39th International Statistical Institute 4: 31-43. 
#' @examples
#'
#' data(PaulinoTb1.1)
#' 
#' str(PaulinoTb1.1)
#'
#' xt <- xtabs(acid ~ veloc + estr, data = PaulinoTb1.1)
#' xt
#'
#' prop.table(xt)
#'
#' mosaicplot(xt, main = NULL,
#'            xlab = "Limite de Velocidade de 90 km/h",
#'            ylab = "Tipo de Estrada")
#'
NULL