#' @name PaulinoTb1.11
#' @title Tamanho de Ninhadas de Ovelhas
#' @description Estudo de fertilidade de ovelhas de vários rebanhos
#'     identificados pela raça e pela quinta onde eram criadas.
#' @format Um \code{data.frame} com 36 observações e 4 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{quinta}}{Quinta onde eram criadas as ovelhas.}
#'
#' \item{\code{raca}}{Raça das ovelhas}
#'
#' \item{\code{borre}}{Número de borregos (filhotes de ovelha) por
#'     ninhada.}
#'
#' \item{\code{ovelh}}{Número de ovelhas.}
#'
#' }
#' @keywords contingência
#' @source Paulino, C. D., Singer, J. M. (2006). Análise de Dados 
#'     Categorizados (1st ed.). São Paulo, SP: Edgard Blucher.
#'     (Tabela 1.11, pág. 13).
#
#' @references Mead, R., Curnow, R. N., Hasted, A. M. (2002).
#'     Statistical Methods in Agricultural and Experimental Biology, 3
#'     sdn, London: Chapman and Hall/CRC.
#' @examples
#'
#' data(PaulinoTb1.11)
#' 
#' str(PaulinoTb1.11)
#' 
#' xt <- xtabs(ovelh ~ quinta + raca + borre, data = PaulinoTb1.11)
#'
#' ftable(xt)
#' ftable(prop.table(xt))
#'
#' library(vcd)
#'
#' cotabplot(xt)
#'
#' library(lattice)
#'
#' barchart(xt, horizontal = FALSE, beside = FALSE, stack = FALSE,
#'          auto.key = list(space = "top", columns = 4,
#'                          cex.title = 1, rectangles = TRUE,
#'                          points = FALSE,
#'                          title = "Número de borregos"),
#'          xlab = "Quinta",
#'          ylab = "Frequência")
#'
NULL