#' @name PaulinoTb1.12
#' @title Distribuição Espacial de Três Tipos de Árvores
#' @description Com o objetivo de detectar eventual existência de
#'     atração ou repulsão entre três tipos de árvores (carvalhos,
#'     nogueiras e bordos), uma dada zona florestal foi dividida em 576
#'     áreas de tamanho e forma fixos (quadrats) e registrou-se para
#'     cada uma delas a ocorrência ou não de cada tipo de árvore.
#' @format Um \code{data.frame} com 8 observações e 4 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{carv}}{Presença ou ausência da árvore do tipo carvalho.}
#'
#' \item{\code{nogue}}{Presença ou ausência da árvore do tipo nogueira.}
#'
#' \item{\code{bordo}}{Presença ou ausência da árvore do tipo bordo.}
#'
#' \item{\code{ocorr}}{Número de ocorrências de árvores.}
#'
#' }
#' @keywords contingência
#' @source Paulino, C. D., Singer, J. M. (2006). Análise de Dados 
#'     Categorizados (1st ed.). São Paulo, SP: Edgard Blucher.
#'     (Tabela 1.12, pág. 13).
#
#' @references Upton, G. J. G., Fingleton, B. (1985). Spatial Data
#'     Analysis by Example, Vol. 1, New York: John Wiley e Sons. Cap. 3.
#' @examples
#'
#' data(PaulinoTb1.12)
#' 
#' str(PaulinoTb1.12)
#' 
#' xt <- xtabs(ocorr ~ carv + nogue + bordo, data = PaulinoTb1.12)
#'
#' ftable(xt)
#' ftable(prop.table(xt))
#'
#' library(vcd)
#'
#' cotabplot(xt)
#'
NULL