#' @name PaulinoTb1.14
#' @title Novos Casos de Homens com Melanoma
#' @description Num estudo epidemiológico envolvendo a população
#'     norte-americana de homens brancos, realizado entre 1969-1971,
#'     contou-se o número de novos casos de melanoma (tipo de tumor
#'     cancerígeno na pele.)
#' @format Um \code{data.frame} com 12 observações e 3 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{faixa}}{Faixa etária do indivíduo atingido.}
#'
#' \item{\code{regi}}{Região do país em que o indivíduo mora.}
#'
#' \item{\code{melan}}{Número de novos casos de melanoma.}
#'
#' }
#' @keywords contingência
#' @source Paulino, C. D., Singer, J. M. (2006). Análise de Dados 
#'     Categorizados (1st ed.). São Paulo, SP: Edgard Blucher.
#'     (Tabela 1.14, pág. 14).
#
#' @references Gail, M. G. (1978). The analysis of heterogeneity for
#'     indirect standardized mortality ratios, Journal of the Royal
#'     Statistical Society, A 141: 224-234.
#' @examples
#'
#' data(PaulinoTb1.14)
#' 
#' str(PaulinoTb1.14)
#'
#' xt <- xtabs(melan ~ faixa + regi, data = PaulinoTb1.14)
#'
#' ftable(xt)
#' ftable(prop.table(xt))
#'
#' mosaicplot(xt,
#'            main = NULL,
#'            xlab = "Faixa etária",
#'            ylab = "Região")
#'
#' library(lattice)
#'
#' barchart(xt, horizontal = FALSE, beside = TRUE,
#'          auto.key = list(space = "top", columns = 2,
#'                          cex.title = 1, rectangles = TRUE,
#'                          points = FALSE,
#'                          title = "Região"),
#'          xlab = "Faixa etária",
#'          ylab = "Frequência de novos casos de melanoma")
#'
NULL