#' @name PaulinoTb1.2
#' @title Risco de Cárie Dentária em Crianças
#' @description Da população de crianças de 11-13 anos de uma escola
#'     pública foram selecionadas 97, cada uma delas submetida a dois
#'     métodos de averiguação de susceptibilidade à cárie dentária: um
#'     método convencional, de custos elevados, que consiste na contagem
#'     de bactérias do tipo Lactobacillus na saliva, e um método
#'     simpliicado, que se baseia na averiguação da cor resultante da
#'     reação da saliva com a Resarzurina. Esse estudo destinava-se a
#'     avaliar, em particular, a eficácia do método simplificado
#'     relativamente ao método convencional.
#' @format Um \code{data.frame} com 9 observações e 3 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{simpl}}{Risco de cárie segundo o método simplificado
#'     (baixo, médio, alto).}
#'
#' \item{\code{conven}}{Risco de cárie segundo o método convencional
#'     (baixo, médio, alto).}
#'
#' \item{\code{freq}}{Número de crianças observadas na combinação entre
#'     as categorias \code{simpl} e \code{conven}.}
#'
#' }
#' @keywords contingência
#' @source Paulino, C. D., Singer, J. M. (2006). Análise de Dados 
#'     Categorizados (1st ed.). São Paulo, SP: Edgard Blucher.
#'     (Tabela 1.2, pág. 04)
#'
#' @references André, C. D. S., Neves, M. M. C., Tseng. T. H (1990).
#'     Estudo comparativo entre os diferentes métodos de detecção de
#'     indivíduos com alto risco de cárie, Relatório de análise
#'     estatística SEA-RAE-9008, Centro de Estatística Aplicada, IME,
#'     Universidade de São Paulo.
#' @examples
#'
#' data(PaulinoTb1.2)
#' 
#' str(PaulinoTb1.2)
#'
#' xt <- xtabs(freq ~ simpl + conven, data = PaulinoTb1.2)
#' xt
#'
#' prop.table(xt)
#'
#' mosaicplot(xt, main = NULL, cex.axis = 0.9,
#'            xlab = "Método Simplificado",
#'            ylab = "Método Convencional")
#'
NULL