#' @name PaulinoTb1.4
#' @title Graffiti em Sanitários Escolares
#' @description Em 1993 foram inspecionados 28 sanitários masculinos e
#'     28 femininos situados em escolas da área metropolitana de São
#'     Paulo, metade deles em escolas secundárias e a outra metade em
#'     seis escolas do campus principal da Universidade de São Paulo. A
#'     inspeção dos sanitários visou recolher as inscrições verbais e/ou
#'     gráficas (graffiti) neles existentes e que foram depois
#'     clasificadas de acordo com a temática envolvida.
#' @format Um \code{data.frame} com 28 observações e 4 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{tema}}{Tema das inscrições verbais e/ou gráficas.}
#'
#' \item{\code{escol}}{Local onde foi realizado o graffiti.}
#'
#' \item{\code{sexo}}{Sexo do indíviduo que realizou o graffiti.}
#'
#' \item{\code{graf}}{Número de graffiti em sanitários segundo o tema
#'     aludido.}
#'
#' }
#' @keywords contingência
#' @source Paulino, C. D., Singer, J. M. (2006). Análise de Dados 
#'     Categorizados (1st ed.). São Paulo, SP: Edgard Blucher.
#'     (Tabela 1.4, pág. 05)
#'
#' @references Otta. E., Santana, P. R., Lafraia. L. M., Lennenberg, H.,
#'     Teixeira, R. P., Vallochi S. L. (1996). Musa Latrinalis: gender
#'     differences in restroom graffiti., Psychological Reports
#'     78:871-880.
#' @examples
#'
#' data(PaulinoTb1.4)
#' 
#' str(PaulinoTb1.4)
#'
#' xt <- xtabs(graf ~ tema + escol + sexo, data = PaulinoTb1.4)
#'
#' ftable(xt)
#' ftable(prop.table(xt))
#' 
#' library(lattice)
#' 
#' barchart(xt, horizontal = FALSE, beside = FALSE, stack = FALSE,
#'          auto.key = list(space = "top", columns = 2, cex.title = 1,
#'                          rectangles = TRUE, points = FALSE,
#'                          title = "Sexo"),
#'          xlab = "Tema das inscrições",
#'          ylab = "Frequência")
#'
NULL