#' @name PaulinoTb1.8
#' @title Defeitos em Amostras de Fibras Têxteis
#' @description 431 amostras de 100g de fibras têxteis, produzidas por
#'     máquinas de dois fabricantes, foram inspecionadas quanto ao
#'     número registrado de defeitos de cada um dos tipos (botões e
#'     rolhas). Os defeitos do tipo rolha resultam da presença de
#'     entrelaçamento em grupos de fibras maiores e de fácil separação,
#'     já os do tipo botão tem entrelaçamento em grupos de fibras
#'     menores e são de difícil separação. O interesse nesses dados
#'     contra-se na avaliação da intensidade e da homogeneidade da
#'     associação entre as frequências dos dois tipos de defeitos para
#'     os fabricantes.
#' @format Um \code{data.frame} com 18 observações e 4 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{fabr}}{Fabricantes das máquinas (A, B).}
#'
#' \item{\code{bot}}{Número de defeitos do tipo botão (botões).}
#'
#' \item{\code{rolha}}{Número de defeitos do tipo rolha (rolhas).}
#'
#' \item{\code{freq}}{Número de amostras de 100g de fibra têxtil em que
#'     observou-se \code{bot} botões e \code{rolha} rolhas.}
#'
#' }
#' @keywords contingência
#' @source Paulino, C. D., Singer, J. M. (2006). Análise de Dados 
#'     Categorizados (1st ed.). São Paulo, SP: Edgard Blucher.
#'     (Tabela 1.8, pág. 11)
#'
#' @references Ho, L. L., Singer, J. M. (1997). Regression models for
#'     bivariate counts, Brazilian Journal of Probability and Statistics
#'     - REBRAPE 11: 175-197
#' @examples
#' data(PaulinoTb1.8)
#' 
#' str(PaulinoTb1.8)
#'
#' xt <- xtabs(freq ~ fabr + bot + rolha, data = PaulinoTb1.8)
#'
#' ftable(xt)
#' ftable(prop.table(xt))
#'
#' mosaicplot(xt, main = NULL, cex.axis = 0.9,
#'            xlab = "Fabricante das máquinas",
#'            ylab = "Número de botões")
#'
#' library(lattice)
#'
#' barchart(xt, horizontal = FALSE, beside = FALSE, stack = FALSE,
#'          auto.key = list(space = "top", columns = 3,
#'                          cex.title = 1, rectangles = TRUE,
#'                          points = FALSE, title = "Número de rolhas"),
#'          xlab = "Fabricante das máquinas",
#'          ylab = "Frequência do número de defeitos")
#'
NULL