#' @name PaulinoTb1.9
#' @title Grupos Sanguíneos em 3 Amostras
#' @description Distribuições observadas de grupos (fenótipos) de sangue
#'     em 3 amostras de populações de Londres, uma de controle e as
#'     outras de pacientes com úlcera estomacal ou doudenal.
#'     
#' @format Um \code{data.frame} com 12 observações e 3 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{amost}}{Característica da amostra (controle, úlcera
#'     estomacal e duodenal).}
#'
#' \item{\code{sang}}{Grupo sanguíneo (O, A, B, AB).}
#'
#' \item{\code{freq}}{Frequência de pacientes na amostra \code{amost} do
#'     grupo sanguíneo \code{sang}.}
#'
#' }
#' @keywords contingência
#' @source Paulino, C. D., Singer, J. M. (2006). Análise de Dados 
#'     Categorizados (1st ed.). São Paulo, SP: Edgard Blucher.
#'     (Tabela 1.9, pág. 12).
#'
#' @references Elandt-Johnson, R. C. (1971). Probability Models and
#'      Statistical Methods in Genetics, New York: John Wiley e Sons.
#'      (p. 420). 
#' @examples
#'
#' data(PaulinoTb1.9) 
#' 
#' str(PaulinoTb1.9)
#' 
#' xt <- xtabs(freq ~ amost + sang, data = PaulinoTb1.9)
#'
#' xt
#' prop.table(xt)
#'
#' mosaicplot(xt, main = NULL,
#'            xlab = "Amostras",
#'            ylab = "Tipos de sangue")
#'
NULL